#!/opt/concourse/worker/volumes/live/af0515cb-c100-4a5c-4999-8447979a3201/volume/portpicker_1613556367437/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_plac/bin/python
# EASY-INSTALL-SCRIPT: 'portpicker==1.3.1','portserver.py'
__requires__ = 'portpicker==1.3.1'
__import__('pkg_resources').run_script('portpicker==1.3.1', 'portserver.py')
